from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfAttachmentAnnotation(PdfFileAnnotation):
    """
    Represents an attachment annotation.
    """

    @dispatch
    def __init__(self, rectangle: RectangleF, filename: str):
        """
        Initializes a new instance of the PdfAttachmentAnnotation class with the specified rectangle and filename.

        Args:
            rectangle: A RectangleF object representing the rectangle of the annotation.
            filename: A string representing the full path to the file to be attached.
        """
        ptrRec: c_void_p = rectangle.Ptr
        GetDllLibPdf().PdfAttachmentAnnotation_CreatePdfAttachmentAnnotationRF.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfAttachmentAnnotation_CreatePdfAttachmentAnnotationRF.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAttachmentAnnotation_CreatePdfAttachmentAnnotationRF(ptrRec, filename)
        super(PdfAttachmentAnnotation, self).__init__(intPtr)

    @dispatch
    def __init__(self, rectangle: RectangleF, filename: str, stream: Stream):
        """
        Initializes a new instance of the PdfAttachmentAnnotation class with the specified rectangle, filename, and stream.

        Args:
            rectangle: A RectangleF object representing the rectangle of the annotation.
            filename: A string representing the full path to the file to be attached.
            stream: A Stream object representing the stream of the attachment.
        """
        ptrRec: c_void_p = rectangle.Ptr
        ptrStream: c_void_p = stream.Ptr
        GetDllLibPdf().PdfAttachmentAnnotation_CreatePdfAttachmentAnnotationRFS.argtypes = [c_void_p, c_wchar_p, c_void_p]
        GetDllLibPdf().PdfAttachmentAnnotation_CreatePdfAttachmentAnnotationRFS.restype = c_void_p
        intPtr = GetDllLibPdf().PdfAttachmentAnnotation_CreatePdfAttachmentAnnotationRFS(ptrRec, filename, ptrStream)
        super(PdfAttachmentAnnotation, self).__init__(intPtr)

    @property
    def Icon(self) -> 'PdfAttachmentIcon':
        """
        Gets or sets the attachment's icon.

        Returns:
            A PdfAttachmentIcon object specifying the icon for the annotation when it is displayed in closed state.
        """
        GetDllLibPdf().PdfAttachmentAnnotation_get_Icon.argtypes = [c_void_p]
        GetDllLibPdf().PdfAttachmentAnnotation_get_Icon.restype = c_int
        ret = GetDllLibPdf().PdfAttachmentAnnotation_get_Icon(self.Ptr)
        objwrapped = PdfAttachmentIcon(ret)
        return objwrapped

    @Icon.setter
    def Icon(self, value: 'PdfAttachmentIcon'):
        """
        Sets the attachment's icon.

        Args:
            value: A PdfAttachmentIcon object specifying the icon for the annotation when it is displayed in closed state.
        """
        GetDllLibPdf().PdfAttachmentAnnotation_set_Icon.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfAttachmentAnnotation_set_Icon(self.Ptr, value.value)

    @property
    def FileName(self) -> str:
        """
        Gets or sets the full path to the file to be embedded in the PDF file.

        Returns:
            A string value specifying the full path to the file to be embedded in the PDF file.
        """
        GetDllLibPdf().PdfAttachmentAnnotation_get_FileName.argtypes = [c_void_p]
        GetDllLibPdf().PdfAttachmentAnnotation_get_FileName.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfAttachmentAnnotation_get_FileName(self.Ptr))
        return ret

    @FileName.setter
    def FileName(self, value: str):
        """
        Sets the full path to the file to be embedded in the PDF file.

        Args:
            value: A string value specifying the full path to the file to be embedded in the PDF file.
        """
        GetDllLibPdf().PdfAttachmentAnnotation_set_FileName.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfAttachmentAnnotation_set_FileName(self.Ptr, value)
