from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFieldCollection(PdfCollection):
    """
    Represents collection of the Pdf fields.
    """

    @dispatch
    def get_Item(self, index: int) -> PdfField:
        """
        Gets the field at the specified index.
        """

        GetDllLibPdf().PdfFieldCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfFieldCollection_get_Item.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFieldCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else PdfField(intPtr)
        return ret

    @dispatch
    def get_Item(self, name: str) -> PdfField:
        """
        Gets the field with their field name.
        """

        GetDllLibPdf().PdfFieldCollection_get_ItemN.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFieldCollection_get_ItemN.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFieldCollection_get_ItemN(self.Ptr, name)
        ret = None if intPtr == None else PdfField(intPtr)
        return ret

    def Add(self, field: 'PdfField') -> int:
        """
        Adds the specified field.
        :param field: The field item which is added in the PDF form.
        :returns: The field to be added on the page.
        """
        intPtrfield: c_void_p = field.Ptr

        GetDllLibPdf().PdfFieldCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldCollection_Add.restype = c_int
        ret = GetDllLibPdf().PdfFieldCollection_Add(self.Ptr, intPtrfield)
        return ret

    def Insert(self, index: int, field: 'PdfField'):
        """
        Inserts the field at the specified index.
        :param index: The index of the field.
        :param field: The field which should be inserted at the specified index.
        """
        intPtrfield: c_void_p = field.Ptr

        GetDllLibPdf().PdfFieldCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().PdfFieldCollection_Insert(self.Ptr, index, intPtrfield)

    def Contains(self, field: 'PdfField') -> bool:
        """
        Determines whether field is contained within the collection.
        :param field: Check whether object is present in the field collection or not.
        :returns: True if field is present in the collection, otherwise, False.
        """
        intPtrfield: c_void_p = field.Ptr

        GetDllLibPdf().PdfFieldCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldCollection_Contains.restype = c_bool
        ret = GetDllLibPdf().PdfFieldCollection_Contains(self.Ptr, intPtrfield)
        return ret

    def IndexOf(self, field: 'PdfField') -> int:
        """
        Gets the index of the field.
        :param field: The object whose index is requested.
        :returns: Index of the field in collection.
        """
        intPtrfield: c_void_p = field.Ptr

        GetDllLibPdf().PdfFieldCollection_IndexOf.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldCollection_IndexOf.restype = c_int
        ret = GetDllLibPdf().PdfFieldCollection_IndexOf(self.Ptr, intPtrfield)
        return ret

    def Remove(self, field: 'PdfField'):
        """
        Removes the specified field in the collection.
        :param field: The object to be removed from collection.
        """
        intPtrfield: c_void_p = field.Ptr

        GetDllLibPdf().PdfFieldCollection_Remove.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFieldCollection_Remove(self.Ptr, intPtrfield)

    def RemoveAt(self, index: int):
        """
        Removes field at the specified position.
        :param index: The index where to remove the item.
        """
        GetDllLibPdf().PdfFieldCollection_RemoveAt.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfFieldCollection_RemoveAt(self.Ptr, index)

    def Clear(self):
        """
        Clears the form field collection.
        """
        GetDllLibPdf().PdfFieldCollection_Clear.argtypes = [c_void_p]
        GetDllLibPdf().PdfFieldCollection_Clear(self.Ptr)