from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFolder(SpireObject):
    """
    A folder for the purpose of organizing files into a hierarchical structure.
    The structure is represented by a tree with a single root folder acting as
    the common ancestor for all other folders and files in the collection.
    """

    @property
    def Name(self) -> str:
        """
        (Required; ExtensionLevel3) A file name representing the name of the folder.
        Two sibling folders shall not share the same name following case normalization.
        Note: Descriptions of file name and case normalization follow this table.
        """
        GetDllLibPdf().PdfFolder_get_Name.argtypes = [c_void_p]
        GetDllLibPdf().PdfFolder_get_Name.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfFolder_get_Name(self.Ptr))
        return ret

    @dispatch
    def AddFile(self, filePath: str):
        """
        Add a local file into this folder.
        :param filePath: The local file path.
        """
        GetDllLibPdf().PdfFolder_AddFile.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFolder_AddFile(self.Ptr, filePath)

    @dispatch
    def AddFile(self, fileName: str, stream: Stream):
        """
        Add a stream into this folder.
        :param fileName: The file name of the stream.
        :param stream: The stream.
        """
        intPtrstream: c_void_p = stream.Ptr
        GetDllLibPdf().PdfFolder_AddFileFS.argtypes = [c_void_p, c_wchar_p, c_void_p]
        GetDllLibPdf().PdfFolder_AddFileFS(self.Ptr, fileName, intPtrstream)

    def DeleteFile(self, file: 'PdfAttachment'):
        """
        Delete the file in this folder.
        :param file: The file.
        """
        intPtrfile: c_void_p = file.Ptr
        GetDllLibPdf().PdfFolder_DeleteFile.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFolder_DeleteFile(self.Ptr, intPtrfile)

    def CreateSubfolder(self, folderName: str) -> 'PdfFolder':
        """
        Create a subfolder.
        :param folderName: The subfolder name.
        :returns: The PdfFolder.
        """
        GetDllLibPdf().PdfFolder_CreateSubfolder.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFolder_CreateSubfolder.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFolder_CreateSubfolder(self.Ptr, folderName)
        ret = None if intPtr == None else PdfFolder(intPtr)
        return ret

    def DeleteSubfolder(self, folderName: str):
        """
        Delete a subfolder.
        :param folderName: The subfolder name.
        """
        GetDllLibPdf().PdfFolder_DeleteSubfolder.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFolder_DeleteSubfolder(self.Ptr, folderName)

    def HasSubfolders(self) -> bool:
        """
        Whether has subfolders.
        :returns: True or False
        """
        GetDllLibPdf().PdfFolder_HasSubfolders.argtypes = [c_void_p]
        GetDllLibPdf().PdfFolder_HasSubfolders.restype = c_bool
        ret = GetDllLibPdf().PdfFolder_HasSubfolders(self.Ptr)
        return ret

    def Clear(self):
        """
        Clear this folder.
        """
        GetDllLibPdf().PdfFolder_Clear.argtypes = [c_void_p]
        GetDllLibPdf().PdfFolder_Clear(self.Ptr)

    def AddExistFolder(self, folderPath: str):
        """
        Add local folder into this folder.
        :param folderPath: The local folder path.
        """
        GetDllLibPdf().PdfFolder_AddExistFolder.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfFolder_AddExistFolder(self.Ptr, folderPath)