from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfPolygonAnnotation(PdfAnnotation):
    """
    Represents a polygon annotation.
    """
    @dispatch
    def __init__(self, page: PdfPageBase, points: List[PointF]):
        """
        Initializes a new instance of the PdfPolygonAnnotation class.

        Args:
            page (PdfPageBase): The page to which the annotation belongs.
            points (List[PointF]): The list of points that define the polygon.
        """
        ptrPage: c_void_p = page.Ptr

        countnewValues = len(points)
        ArrayTypenewValues = c_void_p * countnewValues
        arraynewValues = ArrayTypenewValues()
        for i in range(0, countnewValues):
            arraynewValues[i] = points[i].Ptr

        GetDllLibPdf().PdfPolygonAnnotation_CreatePdfPolygonAnnotationPP.argtypes = [c_void_p, ArrayTypenewValues, c_int]
        GetDllLibPdf().PdfPolygonAnnotation_CreatePdfPolygonAnnotationPP.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPolygonAnnotation_CreatePdfPolygonAnnotationPP(ptrPage, arraynewValues, countnewValues)
        super(PdfPolygonAnnotation, self).__init__(intPtr)

    @property
    def Author(self) -> str:
        """
        Gets or sets the user who created the annotation.
        """
        GetDllLibPdf().PdfPolygonAnnotation_get_Author.argtypes = [c_void_p]
        GetDllLibPdf().PdfPolygonAnnotation_get_Author.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfPolygonAnnotation_get_Author(self.Ptr))
        return ret

    @Author.setter
    def Author(self, value: str):
        """
        Sets the user who created the annotation.

        Args:
            value (str): The user who created the annotation.
        """
        GetDllLibPdf().PdfPolygonAnnotation_set_Author.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfPolygonAnnotation_set_Author(self.Ptr, value)

    @property
    def Subject(self) -> str:
        """
        Gets or sets the description of the annotation.
        """
        GetDllLibPdf().PdfPolygonAnnotation_get_Subject.argtypes = [c_void_p]
        GetDllLibPdf().PdfPolygonAnnotation_get_Subject.restype = c_void_p
        ret = PtrToStr(GetDllLibPdf().PdfPolygonAnnotation_get_Subject(self.Ptr))
        return ret

    @Subject.setter
    def Subject(self, value: str):
        """
        Sets the description of the annotation.

        Args:
            value (str): The description of the annotation.
        """
        GetDllLibPdf().PdfPolygonAnnotation_set_Subject.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfPolygonAnnotation_set_Subject(self.Ptr, value)

    @property
    def ModifiedDate(self) -> 'DateTime':
        """
        Gets or sets the date and time when the annotation was most recently modified.
        """
        GetDllLibPdf().PdfPolygonAnnotation_get_ModifiedDate.argtypes = [c_void_p]
        GetDllLibPdf().PdfPolygonAnnotation_get_ModifiedDate.restype = c_void_p
        intPtr = GetDllLibPdf().PdfPolygonAnnotation_get_ModifiedDate(self.Ptr)
        ret = None if intPtr == None else DateTime(intPtr)
        return ret

    @ModifiedDate.setter
    def ModifiedDate(self, value: 'DateTime'):
        """
        Sets the date and time when the annotation was most recently modified.

        Args:
            value ('DateTime'): The date and time when the annotation was most recently modified.
        """
        GetDllLibPdf().PdfPolygonAnnotation_set_ModifiedDate.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfPolygonAnnotation_set_ModifiedDate(self.Ptr, value.Ptr)

    @property
    def BorderEffect(self) -> 'PdfBorderEffect':
        """
        Gets or sets the border effect.
        """
        GetDllLibPdf().PdfPolygonAnnotation_get_BorderEffect.argtypes = [c_void_p]
        GetDllLibPdf().PdfPolygonAnnotation_get_BorderEffect.restype = c_int
        ret = GetDllLibPdf().PdfPolygonAnnotation_get_BorderEffect(self.Ptr)
        objwraped = PdfBorderEffect(ret)
        return objwraped

    @BorderEffect.setter
    def BorderEffect(self, value: 'PdfBorderEffect'):
        """
        Sets the border effect.

        Args:
            value ('PdfBorderEffect'): The border effect.
        """
        GetDllLibPdf().PdfPolygonAnnotation_set_BorderEffect.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfPolygonAnnotation_set_BorderEffect(self.Ptr, value.value)

    @staticmethod
    def RADIUS() -> float:
        """
        Gets the radius.
        """
        # GetDllLibPdf().PdfPolygonAnnotation_RADIUS.argtypes=[]
        GetDllLibPdf().PdfPolygonAnnotation_RADIUS.restype = c_float
        ret = GetDllLibPdf().PdfPolygonAnnotation_RADIUS()
        return ret