from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfRadialGradientBrush(PdfGradientBrush):
    """
    Represent radial gradient brush.
    """

    @dispatch
    def __init__(self, centreStart: PointF, radiusStart: float, centreEnd: PointF, radiusEnd: float, colorStart: PdfRGBColor, colorEnd: PdfRGBColor):
        """
        Initializes a new instance of the PdfRadialGradientBrush class.
        
        Args:
            centreStart (PointF): The starting center point of the gradient.
            radiusStart (float): The starting radius of the gradient.
            centreEnd (PointF): The ending center point of the gradient.
            radiusEnd (float): The ending radius of the gradient.
            colorStart (PdfRGBColor): The starting color of the gradient.
            colorEnd (PdfRGBColor): The ending color of the gradient.
        """
        ptrcentreStart: c_void_p = centreStart.Ptr
        ptrcentreEnd: c_void_p = centreEnd.Ptr
        ptrcolorStart: c_void_p = colorStart.Ptr
        ptrcolorEnd: c_void_p = colorEnd.Ptr

        GetDllLibPdf().PdfRadialGradientBrush_CreatePdfRadialGradientBrushCRCRCC.argtypes = [c_void_p, c_float, c_void_p, c_float, c_void_p, c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_CreatePdfRadialGradientBrushCRCRCC.restype = c_void_p
        intPtr = GetDllLibPdf().PdfRadialGradientBrush_CreatePdfRadialGradientBrushCRCRCC(ptrcentreStart, radiusStart, ptrcentreEnd, radiusEnd, ptrcolorStart, ptrcolorEnd)
        super(PdfRadialGradientBrush, self).__init__(intPtr)

    @property
    def Blend(self) -> 'PdfBlend':
        """
        Gets or sets a PdfBlend that specifies positions and factors that define a custom falloff for the gradient.
        """
        GetDllLibPdf().PdfRadialGradientBrush_get_Blend.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_get_Blend.restype = c_void_p
        intPtr = GetDllLibPdf().PdfRadialGradientBrush_get_Blend(self.Ptr)
        ret = None if intPtr == None else PdfBlend(intPtr)
        return ret

    @Blend.setter
    def Blend(self, value: 'PdfBlend'):
        """
        Sets a PdfBlend that specifies positions and factors that define a custom falloff for the gradient.
        
        Args:
            value (PdfBlend): The PdfBlend to set.
        """
        GetDllLibPdf().PdfRadialGradientBrush_set_Blend.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_set_Blend(self.Ptr, value.Ptr)

    @property
    def InterpolationColors(self) -> 'PdfColorBlend':
        """
        Gets or sets a ColorBlend that defines a multicolor linear gradient.
        """
        GetDllLibPdf().PdfRadialGradientBrush_get_InterpolationColors.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_get_InterpolationColors.restype = c_void_p
        intPtr = GetDllLibPdf().PdfRadialGradientBrush_get_InterpolationColors(self.Ptr)
        ret = None if intPtr == None else PdfColorBlend(intPtr)
        return ret

    @InterpolationColors.setter
    def InterpolationColors(self, value: 'PdfColorBlend'):
        """
        Sets a ColorBlend that defines a multicolor linear gradient.
        
        Args:
            value (PdfColorBlend): The PdfColorBlend to set.
        """
        GetDllLibPdf().PdfRadialGradientBrush_set_InterpolationColors.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_set_InterpolationColors(self.Ptr, value.Ptr)

    @property
    def Rectangle(self) -> 'RectangleF':
        """
        Gets or sets the rectangle.
        """
        GetDllLibPdf().PdfRadialGradientBrush_get_Rectangle.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_get_Rectangle.restype = c_void_p
        intPtr = GetDllLibPdf().PdfRadialGradientBrush_get_Rectangle(self.Ptr)
        ret = None if intPtr == None else RectangleF(intPtr)
        return ret

    @Rectangle.setter
    def Rectangle(self, value: 'RectangleF'):
        """
        Sets the rectangle.
        
        Args:
            value (RectangleF): The RectangleF to set.
        """
        GetDllLibPdf().PdfRadialGradientBrush_set_Rectangle.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_set_Rectangle(self.Ptr, value.Ptr)

    @property
    def Extend(self) -> 'PdfExtend':
        """
        Gets or sets the value indicating whether the gradient should extend starting and ending points.
        """
        GetDllLibPdf().PdfRadialGradientBrush_get_Extend.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_get_Extend.restype = c_int
        ret = GetDllLibPdf().PdfRadialGradientBrush_get_Extend(self.Ptr)
        objwrapped = PdfExtend(ret)
        return objwrapped

    @Extend.setter
    def Extend(self, value: 'PdfExtend'):
        """
        Sets the value indicating whether the gradient should extend starting and ending points.
        
        Args:
            value (PdfExtend): The PdfExtend to set.
        """
        GetDllLibPdf().PdfRadialGradientBrush_set_Extend.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfRadialGradientBrush_set_Extend(self.Ptr, value.value)

    def Clone(self) -> 'PdfBrush':
        """
        Creates a new copy of a brush.
        
        Returns:
            PdfBrush: A new instance of the Brush class.
        """
        GetDllLibPdf().PdfRadialGradientBrush_Clone.argtypes = [c_void_p]
        GetDllLibPdf().PdfRadialGradientBrush_Clone.restype = c_void_p
        intPtr = GetDllLibPdf().PdfRadialGradientBrush_Clone(self.Ptr)
        ret = None if intPtr == None else PdfBrush(intPtr)
        return ret