from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfStampCollection(PdfCollection):
    """
    A collection of stamps that are applied to the page templates.
    """

    def get_Item(self, index: int) -> 'PdfPageTemplateElement':
        """
        Gets a stamp element by its index.
        """
        GetDllLibPdf().PdfStampCollection_get_Item.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfStampCollection_get_Item.restype = c_void_p
        intPtr = GetDllLibPdf().PdfStampCollection_get_Item(self.Ptr, index)
        ret = None if intPtr == None else PdfPageTemplateElement(intPtr)
        return ret

    @dispatch
    def Add(self, template: PdfPageTemplateElement) -> int:
        """
        Adds a stamp element to the collection.
        Args:
            template: The stamp element.
        Returns:
            The index of the stamp element.
        """
        intPtrtemplate: c_void_p = template.Ptr
        GetDllLibPdf().PdfStampCollection_Add.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfStampCollection_Add.restype = c_int
        ret = GetDllLibPdf().PdfStampCollection_Add(self.Ptr, intPtrtemplate)
        return ret

    @dispatch
    def Add(self, x: float, y: float, width: float, height: float) -> PdfPageTemplateElement:
        """
        Creates a stamp element and adds it to the collection.
        Args:
            x: X co-ordinate of the stamp.
            y: Y co-ordinate of the stamp.
            width: Width of the stamp.
            height: Height of the stamp.
        Returns:
            The created stamp element.
        """
        GetDllLibPdf().PdfStampCollection_AddXYWH.argtypes = [c_void_p, c_float, c_float, c_float, c_float]
        GetDllLibPdf().PdfStampCollection_AddXYWH.restype = c_void_p
        intPtr = GetDllLibPdf().PdfStampCollection_AddXYWH(self.Ptr, x, y, width, height)
        ret = None if intPtr == None else PdfPageTemplateElement(intPtr)
        return ret

    def Contains(self, template: 'PdfPageTemplateElement') -> bool:
        """
        Checks whether the stamp element exists in the collection.
        Args:
            template: Stamp element.
        Returns:
            True - if stamp element exists in the collection, False otherwise.
        """
        intPtrtemplate: c_void_p = template.Ptr
        GetDllLibPdf().PdfStampCollection_Contains.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfStampCollection_Contains.restype = c_bool
        ret = GetDllLibPdf().PdfStampCollection_Contains(self.Ptr, intPtrtemplate)
        return ret

    def Insert(self, index: int, template: 'PdfPageTemplateElement'):
        """
        Inserts a stamp element to the collection at the specified position.
        Args:
            index: The index of the stamp in the collection.
            template: The stamp element.
        """
        intPtrtemplate: c_void_p = template.Ptr
        GetDllLibPdf().PdfStampCollection_Insert.argtypes = [c_void_p, c_int, c_void_p]
        GetDllLibPdf().PdfStampCollection_Insert(self.Ptr, index, intPtrtemplate)

    def Remove(self, template: 'PdfPageTemplateElement'):
        """
        Removes the stamp element from the collection.
        Args:
            template: The stamp element.
        """
        intPtrtemplate: c_void_p = template.Ptr
        GetDllLibPdf().PdfStampCollection_Remove.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfStampCollection_Remove(self.Ptr, intPtrtemplate)

    def RemoveAt(self, index: int):
        """
        Removes a stamp element from the specified position in the collection.
        Args:
            index: The index of the stamp in the collection.
        """
        GetDllLibPdf().PdfStampCollection_RemoveAt.argtypes = [c_void_p, c_int]
        GetDllLibPdf().PdfStampCollection_RemoveAt(self.Ptr, index)

    def Clear(self):
        """
        Cleares the collection.
        """
        GetDllLibPdf().PdfStampCollection_Clear.argtypes = [c_void_p]
        GetDllLibPdf().PdfStampCollection_Clear(self.Ptr)

    def GetEnumerator(self) -> 'IEnumerator':
        """
        """
        GetDllLibPdf().PdfStampCollection_GetEnumerator.argtypes = [c_void_p]
        GetDllLibPdf().PdfStampCollection_GetEnumerator.restype = c_void_p
        intPtr = GetDllLibPdf().PdfStampCollection_GetEnumerator(self.Ptr)
        ret = None if intPtr == None else IEnumerator(intPtr)
        return ret